componenttools.iterate_components_backward_in_expr
==================================================

.. autofunction:: abjad.tools.componenttools.iterate_components_backward_in_expr.iterate_components_backward_in_expr
